jsonschema: Implementation of JSON Schema validation for Python
===============================================================

Description
-----------

Implementation of JSON Schema validation for Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/jsonschema/

